CA11_Cl01.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Users |
clickAndWait | link=Añadir usuario |
type | id_username | usuriodeprueba
type | id_password1 | 1234º
type | id_password2 | 1234º
clickAndWait | _continue |
clickAndWait | link=Terminar sesión |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Users |
clickAndWait | link=usuriodeprueba |
type | id_username |
type | id_password |
type | id_last_login_0 |
type | id_last_login_1 |
type | id_date_joined_0 |
type | id_date_joined_1 |
clickAndWait | _continue |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | exact:Usuario: |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | Contraseña: |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | Último inicio de sesión: |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |